package org.wso2.registry.lifecycle;

import org.wso2.registry.Resource;
import org.wso2.registry.Registry;
import org.wso2.registry.RegistryException;
import org.wso2.registry.jdbc.handlers.RequestContext;

import java.util.List;

public abstract class Lifecycle {
    public static final String AVAILABLE_LIFE_CYCLES = "Lifecycles";

    private String name;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    /**
     * Associate a new Resource with this lifecycle.  This could set custom properties, create
     * sub-directories, etc...  If this throws an Exception, the association has FAILED.
     *
     * @param resource Resource which we want to change the state
     * @param registry Current registry instance
     * @throws org.wso2.registry.RegistryException
     *          If the condition is not met or some thing is wrong
     */
    public abstract void associate(Resource resource, Registry registry) throws RegistryException;

    /**
     * Do something (change state) - action names are lifecycle-specific, and it's up to the
     * implementation to decide if a given transition is allowed, and what to do if so.
     *
     * @param context the RequestContext containing all the state about this request
     * @param action  action to perform
     * @throws org.wso2.registry.RegistryException
     *          If the condition is not met or some thing is wrong
     */
    public abstract void transition(RequestContext context, String action) throws RegistryException;

    /**
     * Get a list of available actions for the resource in the RequestContext, taking into account
     * current state, user, etc.
     *
     * @param context the RequestContext containing info about the Resource, Registry, User, etc.
     * @return a String[] of the names of valid actions for this lifecycle on the specified resource
     */
    public abstract String [] getAvailableActions(RequestContext context);
}
