/*
 * Copyright (c) 2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc;

import junit.framework.TestCase;
import org.wso2.registry.*;
import org.wso2.registry.app.RegistryServer;

import java.util.ArrayList;
import java.util.List;

public class LifeCycleTest extends TestCase {
    /**
     * Registry instance for use in tests. Note that there should be only one Registry instance in a
     * JVM.
     */
    protected static Registry registry = null;
    RegistryServer server = new RegistryServer();

    public void setUp() {
        try {
            if (registry == null) {
                server.start();
                System.setProperty("in-memory", "false");
                registry = (Registry)System.getProperties().get(RegistryConstants.REGISTRY);
            }
        } catch (Exception e) {
            fail("Failed to initialize the registry.");
        }
    }

    public void testLifecycle() throws RegistryException {

        Resource r1 = registry.newResource();
        byte[] r1content = "R1 content".getBytes();
        r1.setContent(r1content);
        registry.put("/d12/r1", r1);

        String comment1 = "this can be used as a test resource.";
        String comment2 = "I like this";
        registry.addComment("/d12/r1", new Comment(comment1));
        registry.addComment("/d12/r1", new Comment(comment2));

        Comment[] comments = registry.getComments("/d12/r1");
        assertNotNull(registry.get("/d12/r1").getContent());

        boolean commentFound = false;
        for (Comment comment : comments) {
            if (comment.getText().equals(comment1)) {
                commentFound = true;
                break;
            }
        }
        assertTrue("comment '" + comment1 +
                   "' is not associated with the artifact /d12/r1", commentFound);

        Resource commentsResource = registry.get("/d12/r1;comments");
        assertTrue("Comment collection resource should be a directory.",
                   commentsResource instanceof Collection);
        comments = (Comment[])commentsResource.getContent();

        List commentTexts = new ArrayList();
        for (Comment comment : comments) {
            Resource commentResource = registry.get(comment.getCommentPath());
            commentTexts.add(commentResource.getContent());
        }

        assertTrue(comment1 + " is not associated for resource /d12/r1.",
                   commentTexts.contains(comment1));
        assertTrue(comment2 + " is not associated for resource /d12/r1.",
                   commentTexts.contains(comment2));

        registry.associateLifeCycle("/d12/r1", "default");

        registry.lifeCycleTransition("/d12/r1", "default", "promote");

        Resource resource = registry.get("/developed/d12/r1");
        assertNotNull(resource);
        assertNotNull(resource.getContent());

        comments = registry.getComments("/developed/d12/r1");

        commentFound = false;
        for (Comment comment : comments) {
            if (comment.getText().equals(comment1)) {
                commentFound = true;
                break;
            }
        }
        assertTrue("comment '" + comment1 +
                   "' is not associated with the artifact /developed/d12/r1", commentFound);

        commentsResource = registry.get("/developed/d12/r1;comments");
        assertTrue("Comment collection resource should be a directory.",
                   commentsResource instanceof Collection);
        comments = (Comment[])commentsResource.getContent();

        commentTexts = new ArrayList();
        for (Comment comment : comments) {
            Resource commentResource = registry.get(comment.getCommentPath());
            commentTexts.add(commentResource.getContent());
        }

        assertTrue(comment1 + " is not associated for resource /developed/d12/r1.",
                   commentTexts.contains(comment1));
        assertTrue(comment2 + " is not associated for resource /developed/d12/r1.",
                   commentTexts.contains(comment2));

    }
}
